# Communications Team Handbook

This document defines communications activities needed to run a
Kubernetes Contributor Summit (KCS). The Comms Team consists of 1-2 lead(s), shadows, volunteers, at least 1 emeritus lead, and a Website Manager.

Comms Leads are responsible for leading the comms team, training shadows, and ensuring all comms activities are planned, prioritized, and completed successfully. They are committed to run the comms team for the current cycle and advise as Emeritus KCS Comms Lead in the following comms cycle (2 cycles, 1 year). Must have [Kubernetes Org Membership]. Expected to attend in-person.

Shadows will learn both how to do comms and how to run the KCS Comms team, as directed by the Comms Lead. They are committing to be involved with the event team for 1.5 years or 3 comms cycles (shadow, lead, and emeritus). Must either have [Kubernetes Org Membership] or be planning to pursue org membership.

Volunteers are expected to assist with comms during the current KCS cycle, as directed by the lead. Volunteers do not need to have or be pursuing [Kubernetes Org Membership].

An emeritus comms lead is a past lead who provides mentorship to the current comms lead. Should have [Kubernetes Org Membership].

The Website Manager is responsible for ensuring updates to the [Kubernetes Contributor Website](k8s.dev) happen. Requires [Kubernetes Org Membership]

- [KCS Comms Lead Overview](#kcs-comms-lead-overview)
- [Shadow to the KCS Comms Lead Role](#shadow-to-the-kcs-comms-lead-role)
- [KCS Comms Volunteer Overview](#kcs-comms-volunteer-overview)
- [KCS Website Manager Overview](#kcs-website-manager-overview)
- [Emeritus KCS Comms Lead Overview](#kcs-website-manager-overview)
- [Comms Rules and Guidelines](#comms-rules-and-guidelines)
- [Documentation](#documentation)

## KCS Comms Lead Overview

A KCS Comms Lead should plan to be involved with KCS planning for at least a year (2 KCS events), first as lead (for 1 or more events), and then as an emeritus mentor to the succeeding Comms lead (for 1 or more events). The workload of being an Emeritus Comms Lead is light, but they are still actively involved.

A KCS Comms Lead holds that role from the beginning of planning for a specific KCS event until all activities for that event are completed, including post-event activities such as event retros and updating the handbook (this doc). This timeframe is the "cycle" for that KCS event.

As Communications Lead, you are responsible for the overall communications
before, during, and after the event. The role also includes ensuring all non-technical content (web, mail,
physical prints) is correct and informative, and supporting the other roles
(registration, content) as needed.

A Comms Lead should plan to attend their KCS event in-person. Onsite, a Comms lead acts as the contact person for any comms needed onsite, such as messaging about room or registration changes that may occur onsite. In the event that a KCS Comms Lead is unable to attend in-person, the lead is responsible for designating an in-person comms point of contact.

When their cycle is complete, a KCS Comms Lead becomes "emeritus." The most recent Emeritus Comms Lead should plan to be actively involved in the following KCS cycle as a mentor to the next KCS Comms Lead.

Time Commitment:
- 1-3 hours a week from 0-1.5 months in
- 3-5 hours a week from 1.5 months-to event
- 1-3 hours post-event for retros and handbook updates
- 1-2 hours per month through the following KCS cycle.

### Skills and Qualifications

- A KCS Comms Lead must have [Kubernetes Org Membership]. (They should not plan to pursue membership during the cycle.)
- A KCS Comms Lead should plan to attend their KCS event in-person
- Successful completion of a past cycle as a KCS Comms Shadow, or equivalent experience
- Good grasp on general comms activities surrounding events
- Understanding of common forms of contributor communications including Slack, email, and contributor-owned social media accounts
- A healthy emoji vocabulary!

### Responsibilities

- Create a Comms Team plan for the cycle
  - Create a KCS Comms Team plan using the [KCS Comms Team Plan Template]
    - Shadow requirements
    - Volunteer requirements
    - Associated activities such as comms and meeting updates
    - Update the included rough comms timelines
- Create a doc for comms drafts using the [KCS Comms Draft Doc Template]
  - This includes email, Slack, and social media (via the Buffer platform with Contributor Comms)
  - You'll source the informaton needed from your fellow leads, and can refer to prior art (linked below)
- Manage online presence of the website, alongside the social media strategy
- Recruit a website lead to handle all updates to the website
  - Consider ensuring website reviewers/approvers are on the team to merge upstream changes
- Provide updates on social media, mailing lists, and Slack before, during, and after the event
  - After-event communications will include a post-event survey, created by SIG ContribEx leads
- Work alongside the CNCF Events Team to coordinate communications efforts
- Assist with deck content for curated talks and/or other purposes
- Onsite, a Comms lead acts as the contact person for any comms needed onsite, such as messaging about room or registration changes that may occur onsite.

### What to do as KCS Comms Lead
This section acts as a checklist for activities the KCS Comms Lead is likely to do each cycle.

- Create Slack DM with Comms team (lead, shadows, volunteers)
- Create a doc using the [KCS Comms Team Plan Template] & put it in the relevant KCS folder
  - Update shadow & volunteer requirements to suit your team
  - Update Staff Summit Meeting sign up sheet
- Create Email Plan Doc & put it in the relevant KCS folder
- [Optional] Set up meetings with Comms team
- Claim and write the announcement comms (email &/or social, slack, etc.)
- Share Plan Docs with team
  - Ensure shadows and volunteers are signed up for necessary activities
- Ensure comms leading up to the event are planned, prioritized, and completed successfully
- [Post-KCS] Update role handbook
- [Post-KCS] Update KCS Comms Overall Plan Template doc

## Shadow to the KCS Comms Lead Role

Shadows are expected to serve as KCS Comms Leads in a future cycle. During their shadowing cycle(s), Shadows will work closely with the KCS Comms Lead to learn both how to run the KCS Comms team and how to create comms themselves. By signing up to shadow, you are committing to be involved with the event team for 1.5 years or 3 comms cycles (shadow, lead, and emeritus). A Shadow candidate must either have [Kubernetes Org Membership] or be planning to pursue org membership.

[Kubernetes Org Membership] can be obtained through KCS Comms work, and a shadow should complete enough tasks to be eligible for org membership over the course of a cycle. Do note that org membership is an indication of active and continuous contribution to the Kubernetes project/community. Shadows are expected to be committed to contributing to Kubernetes on a long-term basis.

### Requirements
* Review this document.
* A KCS Comms Shadow must either have, or plan to pursue, [Kubernetes Org Membership].
* Commit to contributing to the KCS Staff team for multiple cycles.

## Tasks
During the course of their KCS cycle as a shadow, KCS Comms Shadows are expected to complete tasks including but not limited to:
* Joining the appropriate Slack channels for KCS staff collaboration and for sending comms about KCS to the community
* Working with the Comms Lead and Contributor Comms Subproject to get access to tooling for posting on Kubernetes Contributor-focused social media channels.
* Representing the KCS Comms team in KCS Staff meetings.
* Writing email comms as instructed by the KCS Comms Lead.
* Writing social media comms as instructed by the KCS Comms Lead.
* Reviewing comms written by other shadows, volunteers, or the lead as directed by the KCS Comms Lead

Shadows should work with the Comms Lead to ensure they are getting sufficient experience to feel comfortable taking on the KCS Comms Lead role in a future cycle after completion of a shadow cycle.

In the event a shadow is unable to complete the tasks expected of them as designated by the KCS Comms Lead, they should inform the KCS Comms Lead as early as possible, to the best of their ability. Shadows who are unable to complete the required tasks as designated by the KCS Comms Lead, will be removed from the list of shadows. Upon failure to complete a shadowing cycle, the contributor may request to become a shadow in a future cycle. Successful completion of a shadowing cycle (as determined by the KCS Comms Lead) or equivalent experience is required to become a KCS Comms Lead.

## KCS Comms Volunteer Overview
Volunteers are expected to assist with comms during the current KCS cycle, as directed by the lead. Volunteers do not need to have or be pursuing [Kubernetes Org Membership].

### Requirements
* Review this document.
* Commit to supporting KCS Comms through the current cycle

### Tasks
During the course of their KCS cycle as a volunteer, KCS Comms Volunteers are expected to complete tasks including but not limited to:
* Joining the appropriate Slack channels for KCS staff collaboration and for sending comms about KCS to the community
* Working with the Comms Lead and Contributor Comms Subproject to get access to tooling for posting on Kubernetes Contributor-focused social media channels.
* Writing email comms as instructed by the KCS Comms Lead.
* Writing social media comms as instructed by the KCS Comms Lead.
* [optional] Reviewing comms written by other volunteers, shadows, or the lead as directed by the KCS Comms Lead

## KCS Website Manager
The KCS Website Manager is expected to collaborate with all KCS Staff leads and their teams to understand what changes need to be made to the website, when those changes need to go live, and ensuring that all KCS-related website changes are planned, prioritzed, and completed.

### Requirements
- Review this document.
- [Kubernetes Org Membership]
- Commit to supporting KCS Comms through the current cycle and the following cycle as emeritus Website Manager (1 year, 2 cycles)
- Basic familiarity with the [Kubernetes Contributor Site (k8s.dev)](https://github.com/kubernetes/contributor-site), especially the events section (k8s.dev/events)
- Basic familiarity with the [Hugo website framework](https://gohugo.io/)
- Basic familiarity with the [Markdown](https://www.markdownguide.org/) markup language

### Tasks
During the course of their KCS cycle as a website manager, KCS Website Managers are expected to complete tasks including but not limited to:
- Joining the appropriate Slack channel(s) for KCS staff collaboration
- Creating the page for the specific event within k8s.dev/events
- Adding and maintaining information and pages throughout the event cycle, including:
  - Registration info
  - CFP & schedule info
  - Social venue and registration info
  - and more

## Emeritus KCS Comms Lead Overview
After completing a cycle as a KCS Comms Lead, the former lead takes on emeritus status. As an Emeritus KCS Lead, the former lead is expected to mentor the following KCS Lead(s). The Emeritus Lead can provide mentorship for as long as they like, but it's especially valuable for the previous lead to mentor their direct successor.

### Requirements
- Has completed at least 1 cycle as a KCS Comms Lead
- [Kubernetes Org Membership]

### Tasks
- Provide mentorship to the KCS Comms Lead

## Comms Rules and Guidelines

### Social Media Rules
- Send KCS comms to k8scontributors accounts on whatever platforms they exist on. At time of writing, that’s “X” and Mastodon. Social media should be sent only to contributor-facing accounts.
  - Kubernetesio on X and the Kubernetes Linkedin accounts should not be used because their audiences include end users and the general public..
- Make sure comms are formatted in Arial, 11pt, with single line spacing before copying into the target platform. This will ensure that the text looks consistent wherever it is posted.
- If you are scheduling comms to go out at a specific time, make sure that time is aligned with the timezone the event will be held in.
- Link to k8s.dev/events and subpages, or email messages, wherever possible. Avoid sharing links to contributor-specific links such as Registration, CFP, and GitHub Issues.
  - While our Social Media presence is largely targeted at contributors, all social media posts are public. As such, we should avoid sharing links which could cause unwanted spam/interactions.
- Review the Contributor Comms team’s Social Media Guidelines.
- All social media should have at least 1 review, preferably by a shadow. A review by a social media approver is a given.
- Generally, social media should be ready for review at least 1 day before it needs to be sent.
- Generally, an email should be ready for review around 3 or more days before it needs to be sent.
- If any shadow does not have Buffer access, let the KCS Comms lead know.
- Always consider your intended and actual audience! When a message is only applicable to org members (which is pretty much - everything for the contributor summit), state that clearly!


### Email Tips and rules
- NOTE: A sender’s first email to a mailing list will get stuck in the moderation queue. Include around a day in the delivery estimate to account for the time a sender’s first email will spend in the moderation queue. Shadows & Volunteers should plan to send their first email to a given mailing list (leads, dev, etc) early in the day on the day it’s due. (per the timezone of the location where the summit will be held).
- Make sure comms are formatted in Arial, 11pt, with single line spacing before copying into the target platform. This will ensure that the text looks consistent wherever it is posted.
- An email should be ready for review around 3 or more days before it needs to be sent.
- Send a message to the KCS Comms group dm (this is usually a dm, not a channel) on the #summit-staff channel in Slack when an email is ready for review, and preferably 1 day before it goes out.
- Use your own email address to send to the relevant mailing lists, but add a closing line like “-[name], on behalf of the Summit Staff team”
- Mention that org membership is required in basically every email, particularly anything to do with registration.
- All emails should include summit-team@kubernetes.io in CC each time.
- If you are scheduling comms to go out at a specific time, make sure that time is aligned with the timezone the event will be held in.

### Communication Channels and Property Access

**Email**

Unless you have access to official Kubernetes accounts, please use your own email account
to send all email communications. All emails should include summit-team@kubernetes.io in CC each time.
The Event Lead will add all team leads to this distribution list.
Outbound communications should always target the main distribution list, dev@kubernetes.io, as well
as the co-chairs and tech leads distribution list, leads@kubernetes.io, when necessary.

While it is appreciated that you triage incoming mail for summit-team@kubernetes.io to
varying team leads, you are not responsible for answering all incoming messages. The entire
summit planning team should triage and handle their ownership areas when it comes to email communications,
respectively.

**Website**

The [Contributor Site](https://www.kubernetes.dev/) should be the source of truth for all Contributor Summit information.
As timing, location, registration, and schedule information is confirmed for the event, the website should be populated
as soon as possible. The [`OWNERS`](https://github.com/kubernetes/contributor-site/blob/master/OWNERS) file defines
who can approve upstream changes.

All communications via email and social media should link out to the Contributor Site whenever possible. The
["Events"](https://www.kubernetes.dev/events/) top-level page is where all Contributor Summit information is
organized, by calendar year. 

**Slack**

Slack messaging should be implemented so that all corners of our community are communicated with. Let your emoji power shine!
The following channels will be important for all major announcements, plus most reminders:
- **#contributor-summit**
- **#kubernetes-org-members**
- **#chairs-and-techleads**

Please contact the [SIG ContribEx Contributor Comms team](/communication/contributor-comms/README.md) for access to the Announcement
bot in the Kubernetes Slack, which will be useful for broadcasts. The **#contributor-summit** channel should be used for all day-of
event communications by you and other summit sub-teams. Contributors and attendees will also ask questions here: this channel should
be monitored up until the day of the summit (the Day-of Ops Team will work with you on communications and monitoring on the
day of the event).

**X and Mastodon**

Tweets can be sent from two accounts: [@K8sContributors](https://twitter.com/K8sContributors) and [@Kubernetesio](https://twitter.com/kubernetesio).
Mastodon uses [@K8sContributors](https://hachyderm.io/@K8sContributors) on the hachyderm.io instance.
Messaging is coordinated via Buffer, which is owned by the [SIG ContribEx Contributor Comms team](/communication/contributor-comms/README.md).
Please work with the Contributor Comms team for access.

Announcements, live-tweeting, and pictures are all suitable updates for sharing on social media.
Most emails sent should have this information mirrored on social media, with links out to the
website for further information.

## Documentation

[Events Drive for all KCS files and folders](https://drive.google.com/drive/u/0/folders/1R3vHghBYDkhmlqWMExEGrbDOcIMZUJai)

**Template Docs**

[KCS Comms Team Plan Template]

[KCS Comms Draft Doc Template]

**Plan Docs**

[KCS NA Overall Plan Doc 2024](https://docs.google.com/document/d/1W_fkdGDomeM7QYFIIJicBrLtumIaWm_DvozwBcJQvGc/edit) (First use of template)

[Comms plan for KCS EU 2024](https://docs.google.com/document/d/1Ca36QgYFJIqO_-NJjoAezmhjkXc-kwDaF8QceUabUYg/edit)

[Comms plan for KCS EU 2022](https://docs.google.com/document/d/11Mc_vOgGluoUgL262Wsdzd1gLy0g0pAm5Wtf-Fqc49E/edit?usp=sharing)

[Comms Planning Doc for KCS NA in Detroit, 2022](https://docs.google.com/spreadsheets/d/15wKA75zv0O9ZRvCaDWb_xCx6rtj_wTFE/edit?usp=sharing&ouid=103930683490495267611&rtpof=true&sd=true)

[Comms folder for Contributor Summit EU in Paris, 2024](https://drive.google.com/drive/folders/1m2sRXVp_S37V46jPk9SS3pznFZKq41uI?usp=drive_link)

**Docs for email references:**

[Email comms for KCS NA in Salt Lake City, 2024](https://docs.google.com/document/d/1PJwinjOjaTcvHdOWB8KUidTKiHet2xxOFrsUGc9qr_g/edit)

[Email comms for KCS EU in Paris, 2024](https://docs.google.com/document/d/1Ca36QgYFJIqO_-NJjoAezmhjkXc-kwDaF8QceUabUYg/edit)

[Email comms for KCS EU in Amsterdam, 2023](https://docs.google.com/document/d/1HW48b7q_piCuTJ1zOYsr6WuDcjZLz6bRD62yHr3VPtk/edit#heading=h.gjdgxs)

[Email comms for KCS NA Chicago, 2023](https://docs.google.com/document/d/1HLEBrfJ-H2EtBqQFtgNsDYmXv2pKTF2s4vyEcLjYYvo/edit?usp=sharing)

[Email comms for KCS EU in Valencia, 2022](https://docs.google.com/document/d/1edNsxofCtb3SiPEVzBmBgPEzjni-XI0MYcsnEYoXwLc/edit?usp=sharing)

[Email comms for KCS NA Detroit, 2022](https://docs.google.com/document/d/1zntHy-arEZvR9BHS3krUod3RNeSzr3am9LUF_QQ84bI/edit#heading=h.3znysh7)

[Comms used for KCS EU in Barcelona, 2019](https://github.com/kubernetes/community/blob/master/events/2019/05-contributor-summit/communications.md)

[Email comms for KCS NA 2019 in San Diego](https://docs.google.com/document/d/1EIpaFmrqp3qqXsnGhpr4H-RoFeFSd4dHZJ6M8RwyHBI/edit)


[Kubernetes Org Membership]: [https://github.com/kubernetes/community/blob/master/community-membership.md#member]
[KCS Comms Team Plan Template]: [https://docs.google.com/document/d/1n_QIm_Yov5rt819W34ztQOcCJ3EKa4VMYDR_P-Qk02o/edit?usp=sharing]
[KCS Comms Draft Doc Template]: [https://docs.google.com/document/d/1iNohrTPXP-rpWa9Co2ztwR1kHiA4kzOhJ7Zs6bQRw_I/edit?usp=sharing]